==> linuxconf-1.29r3.bin-elf.tar.gz: usr/lib/linuxconf/help.cs/accountbatch-msg-1.29r3.cs <==
g  accountbatch           H    @  ?  ]  p        8  _              3  H  \  j  w        c  q            /  <  M  Z                    	    M        /  D  N  V  \  b  h  q  |                  	  	  	.  	B  	  	linuxconf --modulemain accountbatch usage

    --help
    --update [--test] [--silent] [--file path] [--group groupname ]
             [--grouplow gid ] [--add ] [--del ] [--mod ]
             [--archive ] [--delfiles ]
             [--passdb log_file ]
 Create/Update from a database Configuration name Data file path Account management You can update the Linux user account database
from another database. This database is either
a flat file, or retrieved using a command. Enter the configuration name No space allowed in configuration name You must provide either a data file
or a command, not both Data command Save configuration No recorded configuration Operate on group above You must provide either a data file
or a command Operate only on groups Add missing accounts Delete old accounts Archive files Delete files Keep files Deletion mode Test All account not part of the list (data file or command)
will be deleted. You must restrict the scope of this action
by supplying either a group list or a minimum group ID
on which the list is authoritative Not specified No user accounts to process Unknown group: %s manage accounts The command %s produced the following error
	%s Specifying a minimum group ID
and a group list is ambiguous Invalid line %d: %s New accounts Deleted accounts Test results No account created, deleted or updated Results Account Name Added Deleted Updated Updated accounts Update existing account password Option --grouplow: Numeric value expected
 Invalid option %s
 Nothing to do: Use --add, --del or --mod option
 You must use either the option --grouplow or --group
to limit the scope of the operation.
Too many accounts would be modified otherwise
 %d accounts added, %d deleted, %d updated
 Adding account %s %s
 Updating account %s %s
 Deleting account %s
 Base info Parsing Login Group Shell Password Field pos. Default value Not supplied Task Preview Here are the first records Id	Name	Group	Shell	Password Preview Login prefix Login %s must start with a letter Generate Password log path Generated passwords Some passwords were generated
You can save those in a file so the user
may be told their password.
Enter the path of the file Unknown group %s No task selected, nothing to do
You must select at least one task:
	Add missing accounts
	Update existing account password
	Delete old accounts 

==> linuxconf-1.30r3.bin-elf.tar.gz: usr/lib/linuxconf/help.cs/accountbatch-msg-1.30r3.cs <==
g  accountbatch          K    L  K  i  |      '  D  k            (  ?  T  h  v          o  }          '  ;  H  Y  f                      (  Y    
  #  ;  P  Z  b  h  n  t  }                  	  	$  	-  	?  	S  	  	  
r  
  
linuxconf --modulemain accountbatch usage

    --help
    --update [--test] [--silent] [--file path] [--group groupname ]
             [--grouplow gid ] [--add ] [--del ] [--mod ]
             [--archive ] [--delfiles ]
             [--passdb log_file ]
 Create/Update from a database Configuration name Data file path Account management You can update the Linux user account database
from another database. This database is either
a flat file, or retrieved using a command. Enter the configuration name No space allowed in configuration name You must provide either a data file
or a command, not both Data command Save configuration No recorded configuration Operate on group above You must provide either a data file
or a command Operate only on groups Add missing accounts Delete old accounts Archive files Delete files Keep files Deletion mode Test All account not part of the list (data file or command)
will be deleted. You must restrict the scope of this action
by supplying either a group list or a minimum group ID
on which the list is authoritative Not specified No user accounts to process Unknown group: %s manage accounts The command %s produced the following error
	%s Specifying a minimum group ID
and a group list is ambiguous Invalid line %d: %s New accounts Deleted accounts Test results No account created, deleted or updated Results Account Name Added Deleted Updated Updated accounts Update existing account password Option --grouplow: Numeric value expected
 Invalid option %s
 Nothing to do: Use --add, --del or --mod option
 You must use either the option --grouplow or --group
to limit the scope of the operation.
Too many accounts would be modified otherwise
 %d accounts added, %d deleted, %d updated
 Adding account %s %s
 Updating account %s %s
 Deleting account %s
 Base info Parsing Login Group Shell Password Field pos. Default value Not supplied Task Preview Here are the first records Id	Name	Group	Shell	Home	Password Preview Login prefix Login %s must start with a letter Generate Password log path Generated passwords Some passwords were generated
You can save those in a file so the user
may be told their password.
Enter the path of the file Unknown group %s No task selected, nothing to do
You must select at least one task:
	Add missing accounts
	Update existing account password
	Delete old accounts Extra fields Format Home directory 
